#ifndef H_CDW_THREAD
#define H_CDW_THREAD

#include "main.h"
#include "cdw_task.h"

/* size of char * buffer, into which cdw will put data read from
   external programs; the data will be then read from the buffer by
   another part of cdw; does not include space for ending '\0' */
#define PIPE_BUFFER_SIZE 1000



int      cdw_thread_run_command(const char *command, cdw_task_t *task);
cdw_rv_t cdw_thread_send_key_to_child_process(int key);

#endif /* #ifndef H_CDW_THREAD */
